summaryrefslogtreecommitdiffhomepage
path: root/pkg/metric/metric.go
diff options
context:
space:
mode:
authorgVisor bot <gvisor-bot@google.com>2021-05-15 00:26:10 +0000
committergVisor bot <gvisor-bot@google.com>2021-05-15 00:26:10 +0000
commit8665ce2587e98bf7c45eccfefd3794525420caf8 (patch)
tree8f3fcd152650627c5019ebedf510d24aca0b463c /pkg/metric/metric.go
parent0f2459decc7e8c6009b13e9093f7bbff7ea3b96f (diff)
parent8e8b752524e1c1558a0858a121bb56ac1b78456c (diff)
Merge release-20210510.0-43-g8e8b75252 (automated)
Diffstat (limited to 'pkg/metric/metric.go')
-rw-r--r--pkg/metric/metric.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/pkg/metric/metric.go b/pkg/metric/metric.go
index 528910d7c..fdeee3a5f 100644
--- a/pkg/metric/metric.go
+++ b/pkg/metric/metric.go
@@ -40,8 +40,8 @@ var (
createdSentryMetrics = false
// WeirdnessMetric is a metric with fields created to track the number
// of weird occurrences such as time fallback, partial_result and
// vsyscall count.
WeirdnessMetric *Uint64Metric
// SuspiciousOperationsMetric is a metric with fields created to detect
@@ -401,10 +401,10 @@ func CreateSentryMetrics() {
createdSentryMetrics = true
- WeirdnessMetric = MustCreateNewUint64Metric("/weirdness", true /* sync */, "Increment for weird occurrences of problems such as time fallback, partial result and vsyscalls invoked in the sandbox.",
+ WeirdnessMetric = MustCreateNewUint64Metric("/weirdness", true /* sync */, "Increment for weird occurrences of problems such as time fallback, partial result, vsyscalls invoked in the sandbox, watchdog startup timeouts and stuck tasks.",
Field{
name: "weirdness_type",
- allowedValues: []string{"time_fallback", "partial_result", "vsyscall_count"},
+ allowedValues: []string{"time_fallback", "partial_result", "vsyscall_count", "watchdog_stuck_startup", "watchdog_stuck_tasks"},
})
SuspiciousOperationsMetric = MustCreateNewUint64Metric("/suspicious_operations", true /* sync */, "Increment for suspicious operations such as opening an executable file to write from a gofer.",
@@ -40,8 +40,8 @@ var (
createdSentryMetrics = false
// WeirdnessMetric is a metric with fields created to track the number
- // of weird occurrences such as time fallback, partial_result and
- // vsyscall count.
+ // of weird occurrences such as time fallback, partial_result, vsyscall
+ // count, watchdog startup timeouts and stuck tasks.
WeirdnessMetric *Uint64Metric
// SuspiciousOperationsMetric is a metric with fields created to detect